from django.db import models
from django.contrib.auth.models import User
import datetime

class Teacher(models.Model):
    user = models.ForeignKey(User , unique=True)
    room = models.CharField(max_length=5)
  
    def __unicode__(self):
        return u'%s in %s' % (self.user.get_full_name() , self.room)
        
    def get_roster(self):
        student_list = Student.objects.filter(seminar=self)
        student_list = sorted(student_list, key=Student.sort_students)
        return student_list
    
    def get_pass_list(self):
        return Pass.objects.filter(destination=self)
        
    def get_incoming_pass_list(self):
        return Pass.objects.filter(destination = self, active = True)
  
class Student(models.Model):
    firstName = models.CharField(max_length=50)
    lastName = models.CharField(max_length=50)
    seminar = models.ForeignKey(Teacher, related_name = "student_roster")
  
    def __unicode__(self):
        return u'%s %s' % (self.firstName, self.lastName)
    
    def get_passes(self):
        return Pass.objects.filter(student=self)
  
    def get_passes_today(self):
        return Pass.objects.filter(student=self , date=datetime.date.today())
    
    def has_pass(self):
        return len(self.get_passes_today()) >= 1
    
    def get_active_pass(self):
        active = Pass.objects.get(active = True, student = self)
        return active
        
    def get_current_room(self):
        active = Pass.objects.get(active = True, student = self)
        return active.destination.room
        
    def sort_students(s):
        if s.has_pass():
            return ord(s.lastName[0])-26
        else:
            return ord(s.lastName[0])
    

class Pass(models.Model):
    student = models.ForeignKey(Student)
    destination = models.ForeignKey(Teacher)
    date = models.DateField("Time of pass")
    note = models.CharField(max_length=200)
    in_transit = models.BooleanField()
    active = models.BooleanField()
            
    def __unicode__(self):
        return u'%s may go to %s on %s' % (self.student,self.destination,self.date)
  
    class Meta:
        ordering = ['date']
